==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/imaging/components/dicomimage/DicomImageComponent.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef DICOMCOMPONENT_H
#define DICOMCOMPONENT_H

#include <QObject>

#include <ImageComponent.h>

class DicomImageComponent : public camitk::ImageComponent {

    Q_OBJECT

public:
    /**
     * Create a new Component that handles DICOM image
     * @param path: the path to a .dcm image file.
     **/
    DicomImageComponent(const QString & path) throw(camitk::AbortException);

    /// Default Destructor
    virtual ~DicomImageComponent();

};

#endif // DICOMCOMPONENT_H

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/imaging/components/dicomimage/DicomImageComponent.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

#ifndef DICOMCOMPONENT_H
#define DICOMCOMPONENT_H

#include <QObject>

#include <ImageComponent.h>
/** 
 * @ingroup group_cepimaging_components_dicomimage
 * 
 * @brief
 * DICOM image Component which handle a single DICOM image.
 * DICOM image is assumed to be of file type .dcm.
 * 
 * @note This @ref camitk::Component "Component" requires the GDCM library in order to work correctly.
 */
class DicomImageComponent : public camitk::ImageComponent {

    Q_OBJECT

public:
    /**
     * Create a new Component that handles DICOM image
     * @param path: the path to a .dcm image file.
     **/
    DicomImageComponent(const QString & path) throw(camitk::AbortException);

    /// Default Destructor
    virtual ~DicomImageComponent();

};

#endif // DICOMCOMPONENT_H
